@@ -20,8 +20,6 @@
 |![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-lambda-stepfunctions`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.lambdastepfunctions`|
 
-## Overview
-
 This AWS Solutions Construct implements an AWS Lambda function connected to an AWS Step Functions.
 
 Here is a minimal deployable pattern definition:
@@ -110,7 +108,7 @@ new LambdaToStepfunctions(this, "test-lambda-stepfunctions-stack",
 |stateMachineProps|[`sfn.StateMachineProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-stepfunctions.StateMachineProps.html)|User provided props for the sfn.StateMachine.|
 |createCloudWatchAlarms|`boolean`|Whether to create recommended CloudWatch alarms|
 |logGroupProps?|[`logs.LogGroupProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroupProps.html)|User provided props to override the default props for for the CloudWatchLogs LogGroup.|
-|stateMachineEnvironmentVariableName?|`string`|Optional Name for the Lambda function environment variable set to the ARN of the state machine. Default: STATE_MACHINE_ARN |
+|stateMachineEnvironmentVariableName?|`string`|Optional Name for the Step Functions state machine environment variable set for the producer Lambda function.|
 |existingVpc?|[`ec2.IVpc`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.IVpc.html)|An optional, existing VPC into which this pattern should be deployed. When deployed in a VPC, the Lambda function will use ENIs in the VPC to access network resources and an Interface Endpoint will be created in the VPC for Amazon Step Functions. If an existing VPC is provided, the `deployVpc` property cannot be `true`. This uses `ec2.IVpc` to allow clients to supply VPCs that exist outside the stack using the [`ec2.Vpc.fromLookup()`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.Vpc.html#static-fromwbrlookupscope-id-options) method.|
 |vpcProps?|[`ec2.VpcProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.VpcProps.html)|Optional user-provided properties to override the default properties for the new VPC. `enableDnsHostnames`, `enableDnsSupport`, `natGateways` and `subnetConfiguration` are set by the pattern, so any values for those properties supplied here will be overrriden. If `deployVpc` is not `true` then this property will be ignored.|
 |deployVpc?|`boolean`|Whether to create a new VPC based on `vpcProps` into which to deploy this pattern. Setting this to true will deploy the minimal, most private VPC to run the pattern:<ul><li> One isolated subnet in each Availability Zone used by the CDK program</li><li>`enableDnsHostnames` and `enableDnsSupport` will both be set to true</li></ul>If this property is `true` then `existingVpc` cannot be specified. Defaults to `false`.|
@@ -151,7 +149,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -170,11 +168,11 @@ import aws_cdk.aws_ec2
 import aws_cdk.aws_lambda
 import aws_cdk.aws_logs
 import aws_cdk.aws_stepfunctions
-import aws_cdk.core
+import constructs
 
 
 class LambdaToStepfunctions(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-lambda-stepfunctions.LambdaToStepfunctions",
 ):
@@ -184,7 +182,7 @@ class LambdaToStepfunctions(
 
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps,
@@ -207,7 +205,7 @@ class LambdaToStepfunctions(
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default properties are used.
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
-        :param state_machine_environment_variable_name: Optional Name for the Lambda function environment variable set to the ARN of the state machine. Default: - STATE_MACHINE_ARN
+        :param state_machine_environment_variable_name: Optional Name for the Step Functions state machine environment variable set for the producer Lambda function. Default: - None
         :param vpc_props: Properties to override default properties if deployVpc is true.
 
         :access: public
@@ -293,7 +291,7 @@ class LambdaToStepfunctionsProps:
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default properties are used.
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
-        :param state_machine_environment_variable_name: Optional Name for the Lambda function environment variable set to the ARN of the state machine. Default: - STATE_MACHINE_ARN
+        :param state_machine_environment_variable_name: Optional Name for the Step Functions state machine environment variable set for the producer Lambda function. Default: - None
         :param vpc_props: Properties to override default properties if deployVpc is true.
 
         :summary: Properties for the LambdaToStepfunctions class.
@@ -391,9 +389,9 @@ class LambdaToStepfunctionsProps:
 
     @builtins.property
     def state_machine_environment_variable_name(self) -> typing.Optional[builtins.str]:
-        '''Optional Name for the Lambda function environment variable set to the ARN of the state machine.
+        '''Optional Name for the Step Functions state machine environment variable set for the producer Lambda function.
 
-        :default: - STATE_MACHINE_ARN
+        :default: - None
         '''
         result = self._values.get("state_machine_environment_variable_name")
         return typing.cast(typing.Optional[builtins.str], result)
